@@ -53,8 +53,10 @@ class db_handler():
         search_query = {'$and':[{'texts': {"$eq":text}},{'lang_code':{"$eq":lang_code}}]}
         result = col.find_one(search_query)
         if result is not None:
-            return result['lang_text']
-        return result
+            if 'lang_text' in result and result['lang_text']:
+                return result['lang_text']
+            return result['google_lang_text']
+        return text
         
     def reverse_translate(self, text):
         table_name = self.mongo_db_table_name
@@ -62,3 +64,7 @@ class db_handler():
         if result is not None:
             return result['texts']
         return text
+
+    def add_new_document(self, table_name, entry_dict):
+        col = self.connected_db[table_name]
+        col.insert_one(entry_dict)
\ No newline at end of file
