@@ -3,13 +3,14 @@ from json import loads
 
 
 def get_context(dispatcher, tracker, domain):
+    print('inside_get_context',tracker.sender_id.lower())
     if 'whatsapp' in tracker.sender_id.lower():
         channel = 'whatsapp'
     elif 'anon' in tracker.sender_id.lower():
         channel = 'gip'
     else:
         # if 'whatsapp' in str(tracker.sender_id) else "gip"
-        channel = 'instagram'
+        channel = 'whatsapp'
     entities = tracker.latest_message["entities"]
     dicts = {}
     for item in entities:
@@ -18,6 +19,7 @@ def get_context(dispatcher, tracker, domain):
     gs_context_dict = tracker.get_slot("gs_context")
     if gs_context_dict is None:
         slots = {}
+        slots['language'] = ""
         active_menu = ""
         active_menu_state = []
         menu_handled = False
