@@ -2,13 +2,13 @@ from json import loads
 from .i18n import i18n_translate
 from . import gs_global
 
+
 def show_response_card(gs_context,current_context,response_details):
     channel = gs_context['channel']
-
     i18n_required = gs_global.global_context['i18n_required']
-    print('15451',i18n_required,gs_context["slots"]['language'],gs_context['menu_handled'])
-    if(i18n_required): #and gs_context["menu_handled"] == False:
-        response_details = i18n_translate(response_details,gs_context["slots"]['language'],channel)
+    lang_code = gs_context["slots"]['language']
+    if(i18n_required):
+        response_details = i18n_translate(response_details,lang_code,channel)
     if response_details['card_type'] == 'list':
         validate_list(channel,response_details)
         list_json = render_list(channel,response_details)
@@ -26,6 +26,9 @@ def show_response_card(gs_context,current_context,response_details):
     elif response_details['card_type'] == 'image':
         img_json = render_image(channel,response_details)
         current_context['response_queue'].append(img_json)
+    elif response_details['card_type'] == 'sticker':
+        sticker_json = render_sticker(channel,response_details)
+        current_context['response_queue'].append(sticker_json)
     elif response_details['card_type'] == 'catalogue':
         catalogue_json = render_catalogue(channel,response_details)
         current_context['response_queue'].append(catalogue_json)
@@ -150,6 +153,8 @@ def render_quick_reply(channel,response_details):
             quick_reply_json['content']['type'] = response_details['content_type']
         if 'url' in response_details.keys():
             quick_reply_json['content']['url'] = response_details['url']
+        if quick_reply_json['content']['type'] == 'text':
+            quick_reply_json['content']['text'] = response_details['text']
         quick_reply_json['msgid'] = 'qr1'
         options_list = []
         for button in response_details['options']:
@@ -199,6 +204,19 @@ def render_image(channel,response_details):
         image_json['previewUrl'] = response_details['url']             
     return image_json
 
+def render_sticker(channel,response_details):
+    sticker_json = {}
+    if channel == 'whatsapp':
+        sticker_json['type'] = 'sticker'
+        sticker_json['url'] = response_details['url']
+    elif channel == 'gip':
+        sticker_json['type'] = 'sticker'
+        sticker_json['url'] = response_details['url']
+    elif channel == 'instagram':
+        sticker_json['type'] = 'sticker'
+        sticker_json['id'] = response_details['id']
+    return sticker_json         
+
 def render_generic_card(channel,response_details):
     generic_json = {}
     if channel == 'whatsapp':
@@ -263,20 +281,36 @@ def behave_extract_bot_response_quick_reply(channel,bot_response):
     if channel == 'whatsapp':
         bot_text = ''
         bot_buttons = []
+        bot_header_url = ''
+        bot_caption = ''
         if len(bot_response) > 1:
             for resp in bot_response:
                 if resp['text'][0] == '{':
                     qr_json = loads(resp['text'])
                     bot_text = qr_json['content']['text']
+                    if qr_json['content']['type'] != 'text':
+                        bot_header_url = qr_json['content']['url']
+                    else:
+                        if 'header' in qr_json['content'].keys():
+                            bot_header_url = qr_json['content']['header']
+                    if 'caption' in qr_json['content'].keys():
+                        bot_caption = qr_json['content']['caption']
                     for option in qr_json['options']:
                         bot_buttons.append(option['title'])  
                     break
         else:
             qr_json = loads(bot_response[0]['text'])
             bot_text = qr_json['content']['text']
+            if qr_json['content']['type'] != 'text':
+                bot_header_url = qr_json['content']['url']
+            else:
+                if 'header' in qr_json['content'].keys():
+                    bot_header_url = qr_json['content']['header']
+            if 'caption' in qr_json['content'].keys():
+                bot_caption = qr_json['content']['caption']
             for option in qr_json['options']:
                 bot_buttons.append(option['title'])
-        return (bot_text.strip(),bot_buttons.sort())
+        return (bot_text.strip(),bot_buttons.sort(),bot_header_url.strip(),bot_caption.strip())
     if channel == 'gip':
         bot_content = ''
         bot_buttons = []
@@ -323,12 +357,30 @@ def behave_compare_quick_reply(channel,input_content,bot_resp):
     if channel == 'whatsapp':
         input_message = input_content['message'].strip()
         button_input = input_content['buttons'].sort()
+        input_content_type = 'text'
+        input_header_url = ''
+        input_caption = ''
+        if 'content_type' in input_content.keys():
+            input_content_type = input_content['content_type']
+        if input_content_type == 'text':
+            if 'header' in input_content.keys():
+                input_header_url = input_content['header']
+        else:
+            input_header_url = input_content['url']
+        if 'caption' in input_content.keys():
+            input_caption = input_content['caption']
         bot_message = bot_resp[0]
         bot_buttons = bot_resp[1]
+        bot_header_url = bot_resp[2]
+        bot_caption = bot_resp[3]
         if (input_message != bot_message):
             return False, "Message comparison failed!"
         if (button_input != bot_buttons):
             return False, "Buttons did not match!"
+        if (input_header_url != '') and (input_header_url.strip() != bot_header_url):
+            return False, "Header/URL did not match!"
+        if (input_caption != '') and (input_caption.strip() != bot_caption):
+            return False, "Caption did not match!"        
         return True, None
     elif channel == 'gip':
         input_content_type = input_content['content_type']
@@ -367,11 +419,15 @@ def behave_extract_bot_response_list(channel,bot_response):
     if channel == 'whatsapp':
         bot_text = ''
         bot_list = []
+        bot_header = ''
+        bot_global_button = ''
         if len(bot_response) > 1:
             for resp in bot_response:
                 if resp['text'][0] == '{':
                     list_json = loads(resp['text'])
                     bot_text = list_json['body']
+                    bot_header = list_json['title']
+                    bot_global_button = list_json['globalButtons']
                     for item in list_json['items']:
                         list_element = {}
                         list_element["Category"] = item['title']
@@ -383,6 +439,8 @@ def behave_extract_bot_response_list(channel,bot_response):
         else:
             list_json = loads(bot_response[0]['text'])
             bot_text = list_json['body']
+            bot_header = list_json['title']
+            bot_global_button = list_json['globalButtons']
             for item in list_json['items']:
                 list_element = {}
                 list_element["Category"] = item['title']
@@ -390,7 +448,7 @@ def behave_extract_bot_response_list(channel,bot_response):
                 for option in item['options']:
                     list_element["Items"].append(option['title'])
                 bot_list.append(list_element)
-        return (bot_text.strip(),bot_list)
+        return (bot_text.strip(),bot_list,bot_header.strip(),bot_global_button)
     elif channel == 'gip':
         bot_items = []
         bot_buttons = []
@@ -415,8 +473,16 @@ def behave_compare_list(channel,input_content,bot_resp):
     if channel == 'whatsapp':
         input_message = input_content['message'].strip()
         list_input = input_content['list']
+        input_header = ''
+        input_global_button = ''
+        if 'header' in input_content.keys():
+            input_header = input_content['header'].strip()
+        if 'globalButtons' in input_content.keys():
+            input_global_button = input_content['globalButtons']
         bot_message = bot_resp[0]
         bot_list = bot_resp[1]
+        bot_header = bot_resp[2]
+        bot_buttons = bot_resp[3]
         list_comparison = True
         for category in list_input:
             category['Items'].sort()
@@ -432,6 +498,10 @@ def behave_compare_list(channel,input_content,bot_resp):
             return False, "Message comparison failed!"
         if (list_comparison == False):
             return False, "List items did not match!"
+        if (input_header != '') and (input_header != bot_header):
+            return False, "Headers did not match!"
+        if (input_global_button != '') and (input_global_button != bot_buttons):
+            return False, "Global Buttons did not match!"
         return True, None
     if channel == 'gip':
         input_items = input_content['items']
@@ -548,6 +618,40 @@ def behave_compare_image(channel,input_content,bot_resp):
             return False, "URLs did not match!"
         return True, None
 
+def behave_extract_bot_response_sticker(channel,bot_response):
+    if channel == 'whatsapp':
+        sticker_json = loads(bot_response[0]['text'])
+        bot_url = sticker_json['url']
+        return bot_url
+    elif channel == 'gip':
+        sticker_json = loads(bot_response[0]['text'])
+        bot_url = sticker_json['url']
+        return bot_url
+    elif channel == 'instagram':
+        sticker_json = loads(bot_response[0]['text'])
+        bot_id = sticker_json['id']
+        return bot_id
+
+def behave_compare_sticker(channel,input_content,bot_resp):
+    if channel == 'whatsapp':
+        input_url = input_content['url']
+        bot_url = bot_resp
+        if (input_url != bot_url):
+            return False, "URLs did not match!"
+        return True, None
+    elif channel == 'gip':
+        input_url = input_content['url']
+        bot_url = bot_resp
+        if (input_url != bot_url):
+            return False, "URLs did not match!"
+        return True, None
+    elif channel == 'instagram':
+        input_url = input_content['id']
+        bot_url = bot_resp
+        if (input_url != bot_url):
+            return False, "IDs did not match!"
+        return True, None 
+
 def behave_extract_bot_response_catalogue(channel,bot_response):
     if channel == 'whatsapp':
         raise Exception('Catalogue not supported in Whatsapp yet!')
@@ -772,3 +876,5 @@ def behave_compare_generic_card_media(channel,input_content,bot_resp):
                 reason = f"Values for Key={key} did not match!"
                 return False, reason
         return True, None
+
+    
